;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gptel" "20251024.2049"
  "Interact with ChatGPT or other LLMs."
  '((emacs     "27.1")
    (transient "0.7.4")
    (compat    "30.1.0.0"))
  :url "https://github.com/karthink/gptel"
  :commit "13baa6754e7b12ce9f0a5a87bf11cf01d1b753d8"
  :revdesc "13baa6754e7b"
  :keywords '("convenience" "tools")
  :authors '(("Karthik Chikmagalur" . "karthik.chikmagalur@gmail.com"))
  :maintainers '(("Karthik Chikmagalur" . "karthik.chikmagalur@gmail.com")))
